<?php 
$OC_Version = array(21,0,6,2);
$OC_VersionString = '21.0.6';
$OC_Edition = '';
$OC_Channel = 'stable';
$OC_VersionCanBeUpgradedFrom = array (
  'nextcloud' => 
  array (
    '20.0' => true,
    '21.0' => true,
  ),
  'owncloud' => 
  array (
    '10.5' => true,
  ),
);
$OC_Build = '2021-11-11T14:55:37+00:00 5b0854cd30ff7d35192e99b83709da3c6c579924';
$vendor = 'nextcloud';
